@@ -1,19 +1,22 @@
 from __future__ import annotations
-from typing import Any, Callable, Container, Dict, Iterable, Iterator, List, NoReturn, Optional, Reversible, Sequence, Set, Sized, TYPE_CHECKING, Tuple, Type, TypeVar, Generic, Union
+from typing import Any, Callable, Container, Dict, Iterable, Iterator, List, NoReturn, Optional, Reversible, Sequence, Set, Sized, TYPE_CHECKING, Tuple, Type, Generic, Union
 
 if TYPE_CHECKING:
     from .lookup import Lookup
     from .grouping import Grouping
+    from .ordered_enumerable import OrderedEnumerable
 
+from .more_typing import (
+    TCollection,
+    TDefault,
+    TInner,
+    TKey,
+    TOther,
+    TResult,
+    TSource_co,
+    TValue,
+)
 
-TSource_co = TypeVar('TSource_co', covariant=True)
-TResult = TypeVar('TResult')
-TDefault = TypeVar('TDefault')
-TOther = TypeVar('TOther')
-TKey = TypeVar('TKey')
-TValue = TypeVar('TValue')
-TCollection = TypeVar('TCollection')
-TInner = TypeVar('TInner')
 
 # do not use this value!!!
 _signal: Any = object()
@@ -474,6 +477,67 @@ class Enumerable(Sequence[TSource_co], Generic[TSource_co]):
             lambda: default,
         )
 
+    def of_type(self, t_result: Type[TResult]) -> Enumerable[TResult]:
+        return self.where(lambda e: isinstance(e, t_result)).cast(t_result)
+
+    def order_by(self,
+        key_selector: Callable[[TSource_co], TKey],
+        *args: Callable[[TKey, TKey], int],
+    ) -> OrderedEnumerable[TSource_co, TKey]:
+        from .ordered_enumerable import OrderedEnumerable
+        if len(args) == 1:
+            comparer = args[0]
+        else:  # len(args) == 2:
+            comparer = None
+        return OrderedEnumerable(
+            self._iter_factory,
+            None,
+            key_selector,
+            comparer,
+            False,
+        )
+
+    def order_by_descending(self,
+        key_selector: Callable[[TSource_co], TKey],
+        *args: Callable[[TKey, TKey], int],
+    ) -> OrderedEnumerable[TSource_co, TKey]:
+        from .ordered_enumerable import OrderedEnumerable
+        if len(args) == 1:
+            comparer = args[0]
+        else:  # len(args) == 2:
+            comparer = None
+        return OrderedEnumerable(
+            self._iter_factory,
+            None,
+            key_selector,
+            comparer,
+            True,
+        )
+
+    def prepend(self, element: TSource_co) -> Enumerable[TSource_co]:  # type: ignore
+        # see self.append()
+        def inner():
+            yield element
+            yield from self
+        return Enumerable(inner)
+
+    @staticmethod
+    def range(start: int, count: Optional[int]) -> Enumerable[int]:
+        if count is not None:
+            if count < 0:
+                raise ValueError('count must be nonnegative')
+            def inner(curr=start, cnt=count):
+                while cnt > 0:
+                    yield curr
+                    curr += 1
+                    cnt -= 1
+        else:
+            def inner(curr=start):
+                while True:
+                    yield curr
+                    curr += 1
+        return Enumerable(inner)
+
     def reverse(self) -> Enumerable[TSource_co]:
         return Enumerable(lambda: self._reversed_impl(fallback=True))
 
