@@ -1,15 +1,20 @@
-from typing import Generic, List, TypeVar
+from __future__ import annotations
+from typing import Generic, List
 
 from .enumerable import Enumerable
 
-
-TKey_co = TypeVar('TKey_co', covariant=True)
-TValue_co = TypeVar('TValue_co', covariant=True)
+from .more_typing import (
+    TKey_co,
+    TValue_co,
+)
 
 
 # kind of respect IGrouping's covariant type parameters if the method _append()
 # is really treated as an internal method
 class Grouping(Enumerable[TValue_co], Generic[TKey_co, TValue_co]):
+    '''
+    Represents a collection of objects that have a common key.
+    '''
 
     _key: TKey_co
     _values: List[TValue_co]
